@@ -208,7 +208,7 @@ constrain.default <- function(x,fun, idx, level=0.95, vcov, estimate=FALSE, ...)
     return(constraints(x,...))
   }
   if (missing(fun)) {
-    if (class(Model(x))[1]=="multigroup" ) {
+    if (inherits(Model(x),"multigroup")) {
       res <- list()
       for (m in Model(x)$lvm) {
         if (length(constrain(m))>0)
@@ -250,7 +250,7 @@ constrain.default <- function(x,fun, idx, level=0.95, vcov, estimate=FALSE, ...)
 
 ##' @export
 "constrain<-.default" <- function(x,par,args,...,value) {
-    if (class(par)[1]=="formula") {
+    if (inherits(par,"formula")) {
         lhs <- getoutcome(par)
         xf <- attributes(terms(par))$term.labels
         par <- lhs
@@ -266,6 +266,7 @@ constrain.default <- function(x,fun, idx, level=0.95, vcov, estimate=FALSE, ...)
     if (is.null(value) || suppressWarnings(is.na(value))) {
         if (!is.null(par)) {
             Model(x)$constrain[[par]] <- NULL
+            Model(x)$constrainY[[par]] <- NULL
         } else {
             Model(x)$constrain[[args]] <- NULL
         }
