@@ -51,9 +51,13 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
                         if (all(is.na(x$fix[e, ]==1)) &
                             is.na(x$covpar[e,e]) & is.na(x$covfix[e,e]))
                             regfix(x,from=e,to=ys.[1]) <- 1
-                        if (!any(unlist(lapply(intercept(x)[ys.],is.numeric))) &
-                            is.na(intercept(x)[[e]]))
-                            intercept(x,ys.[1]) <- 0
+                        if (!any(unlist(lapply(intercept(x)[ys.],is.numeric))) & is.na(intercept(x)[[e]])) {
+                            if (tryCatch(any(idx <- !is.na(x$fix[e,ys.])),error=function(x) FALSE)) {
+                                intercept(x, ys.[which(idx)[1]]) <- 0
+                            } else {
+                                intercept(x,ys.[1]) <- 0
+                            }
+                        }
                     }
                 }
             }
@@ -68,6 +72,7 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
         }
         else {
             S0 <- S
+            S0[is.na(S0)] <- 0
             mu0 <- mu
             e0 <- eigen(S0)
             thres <- lava.options()$itol^(1/2)
